<?php
/**
 * Plugin Name: TextBookers
 * Plugin URI: http://i4a.pl
 * Description: Integracja z textbookers.com
 * Version: 1.00
 * Author URI: http://textbookers.com
 * License: 
 * Text Domain: 
 * Domain Path: /lang
 **/

define('TEXTBOOKERS_VERSION', '1.00');
define('TEXTBOOKERS_DB_VERSION', '1.0');

defined('ABSPATH') or die ("Oops! This is a WordPress plugin and should not be called directly.\n");

register_activation_hook( __FILE__, 'txt_activation' );
register_deactivation_hook( __FILE__, 'txt_deactivation' );

add_action('admin_init', 'txt_admin_init' );
add_action('admin_menu', 'txt_add_options');
add_action('plugins_loaded', 'txt_plugin_init');
add_action('txt_textbookers_hook', 'txt_textbookers');

include plugin_dir_path(__FILE__) . 'class.php';



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function my_enqueue_media_lib_uploader() {

    //Core media script
    wp_enqueue_media();

    // Your custom js file
    wp_register_script( 'media-lib-uploader-js', plugins_url( 'media-lib-uploader.js' , __FILE__ ), array('jquery') );
    wp_enqueue_script( 'media-lib-uploader-js' );
}
add_action('admin_enqueue_scripts', 'my_enqueue_media_lib_uploader');




///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_admin_init() {
	wp_register_style( 'apsStyleSheet', plugins_url('textbookers.css', __FILE__) );
}

function txt_add_options() {
        if (function_exists('add_options_page')) {
                $page = add_options_page(__('TextBookers Options', 'textbookers' ), __('TextBookers', 'textbookers' ), 'manage_options', 'textbookers', 'txt_options_page');
		add_action( 'admin_print_styles-' . $page, 'txt_options_styles' );
        }
}

function txt_plugin_init() {
	$plugin_dir = basename(dirname(__FILE__)) . '/lang';
	load_plugin_textdomain( 'textbookers', false, $plugin_dir );

	// check for plugin update which requires separate check for any db install/changes
	if ( get_option( 'txt_db_version' ) != TEXTBOOKERS_DB_VERSION ) { // database has changed
		txt_db_install();
	}
}

function txt_db_install() {
	global $wpdb;

	include_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

	$wpdb->suppress_errors( false );
	$wpdb->show_errors();

	$charset_collate = '';  // Set default charset and collation
	if ( ! empty( $wpdb->charset ) ) {
		$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset}";
	}
	if ( ! empty( $wpdb->collate ) )  {
		$charset_collate .= " COLLATE {$wpdb->collate}";
	}

	$table_name = $wpdb->prefix . 'textbookers_log';
	$sql = "CREATE TABLE $table_name (
                        id int(11) unsigned NOT NULL AUTO_INCREMENT,
                        date datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        msg text NOT NULL,
                        level tinyint(2) unsigned NOT NULL,
                        UNIQUE KEY id (id)
	) $charset_collate;";

	dbDelta( $sql );

	update_option( 'txt_db_version', TEXTBOOKERS_DB_VERSION );

	$wpdb->hide_errors();
	$wpdb->suppress_errors( true );
	

	
	$wpdb->suppress_errors( false );
	$wpdb->show_errors();

	$charset_collate = '';  // Set default charset and collation
	if ( ! empty( $wpdb->charset ) ) {
		$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset}";
	}
	if ( ! empty( $wpdb->collate ) )  {
		$charset_collate .= " COLLATE {$wpdb->collate}";
	}

	$table_name = $wpdb->prefix . 'textbookers_ordered';
	echo $sql = "CREATE TABLE $table_name (
                        id int(11) unsigned NOT NULL AUTO_INCREMENT,
                        articleTitle text DEFAULT '' NOT NULL,
                        createdAt int(11) DEFAULT '0' NOT NULL,
                        checkedAt int(11) DEFAULT '0' NOT NULL,
                        deadline int(11) DEFAULT '0' NOT NULL,
                        minChars int(11) DEFAULT '0' NOT NULL,
                        author int(11) DEFAULT '0' NOT NULL,
                        individual int(1) DEFAULT '0' NOT NULL,
                        keywords text DEFAULT '' NOT NULL,
                        orderDescription text DEFAULT '' NOT NULL,
                        msg text DEFAULT '' NOT NULL,
                        published int(11) DEFAULT '0' NOT NULL,
                        options text DEFAULT '' NOT NULL,
                        UNIQUE KEY id (id)
	) $charset_collate;";

	dbDelta( $sql );

	update_option( 'txt_db_version', TEXTBOOKERS_DB_VERSION );

	$wpdb->hide_errors();
	$wpdb->suppress_errors( true );
	
	
	
}

function txt_options_styles() {
	wp_enqueue_style('apsStyleSheet');
}

function txt_activation() {
	add_option('txt_enabled', FALSE);
	add_option('txt_next', '24');
	add_option('txt_next_time', __('godzin', 'textbookers' ) );
	add_option('txt_hours_mon', '');
	add_option('txt_hours_tue', '');
	add_option('txt_hours_wed', '');
	add_option('txt_hours_thu', '');
	add_option('txt_hours_fri', '');
	add_option('txt_hours_sat', '');
	add_option('txt_hours_sun', '');
	add_option('txt_debug', 'FALSE');
	add_option('txt_excludes', '');
	add_option('txt_max_per_day', '0');
	add_option('txt_num_day', '0,0');
	add_option('txt_db_version', "0.0" );
	add_option('txt_gt_login', '');
	add_option('txt_gt_pass', '');
	add_option('txt_gt_id_cli', '');
	add_option('txt_gt_sec_cli', '');
}

function txt_deactivation() {
        wp_clear_scheduled_hook('txt_textbookers_hook');
        update_option('txt_enabled', FALSE);
}


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_schedule_event( $restart = 0 ) {
	if ( FALSE == get_option('txt_enabled') ) {	// APS is not enabled - do nothing
		return;
	}
	wp_clear_scheduled_hook('txt_textbookers_hook');
	if ( $restart )
		$timesecs = txt_time_seconds(get_option('txt_next'),get_option('txt_next_time'));
	

	$timestamp = time() + $timesecs;
	$schedules = wp_get_schedules();

	if ( ! is_numeric( $timestamp ) || $timestamp <= 0 ) {
		$str = __("Timestamp ({$timestamp}) must be a positive integer.", 'textbookers' );
	}
	else if ( !isset( $schedules['txt_schedule'] ) ) {
		$str = __("Could not find schedule entry for 'txt_schedule'. Another plugin removed this entry with the 'cron_schedules' filter.", 'textbookers' );
	}
	else if ( wp_schedule_event( time() + $timesecs, 'txt_schedule', 'txt_textbookers_hook' ) !== FALSE ) {
		if ( $restart )
			$str = __("Post published - TextBookers restarted", 'textbookers' );
		else
			$str = __("TextBookers Enabled!", 'textbookers' );
	}
	else {
		$str = __("wp_schedule_event() failed. Another plugin disallowed this event with the 'schedule_event' filter.", 'textbookers' );
	}
	txt_write_log( $str );
	$txt_debug = get_option('txt_debug');
	if ( $txt_debug ) {
		$scheduledtime = wp_next_scheduled('txt_textbookers_hook');
		$formatscheduledtime = date("Y-m-d H:i:s", $scheduledtime + (get_option( 'gmt_offset' ) * HOUR_IN_SECONDS )) . " " . get_option('timezone_string');
		txt_write_log( sprintf( __("DEBUG: First wp_next_scheduled for %s.", 'textbookers'), $formatscheduledtime ) );
	}
	return $str;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_options_page() {

	if (!current_user_can('manage_options')) {
                ?><div id="message" class="error"><p><strong>
		<?php _e('You do not have permission to manage options.', 'textbookers' );?>
            	</strong></p></div><?php
	}
        else if (isset($_POST['enable_auto_post_scheduler'])) {

                ?><div id="message" class="updated fade"><p><strong><?php

                update_option('txt_enabled', TRUE);
		$str = txt_schedule_event();
                echo $str;

		?></strong></p></div><?php

        } else if (isset($_POST['disable_auto_post_scheduler'])) {

                ?><div id="message" class="updated fade"><p><strong><?php

                update_option('txt_enabled', FALSE);
                wp_clear_scheduled_hook('txt_textbookers_hook');
                $str = __("TextBookers Disabled!", 'textbookers' );
                echo $str;
		txt_write_log( $str );

            ?></strong></p></div><?php

        } else if (isset($_POST['clear_log'])) {
		global $wpdb;
		if( current_user_can( 'manage_options' ) ) {
			$table_name = $wpdb->prefix . 'textbookers_log';
			$wpdb->query( 'DELETE FROM ' . $table_name );
		}
        }

        ?>

        <div class='wrap aps'>

        <h2  style="display:inline"><?php _e( 'TextBookers', 'textbookers' );?> v<?php echo TEXTBOOKERS_VERSION; ?>  <form method="post" style="display:inline" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">

        <?php _e( '<small>Pobieranie tekstów:</small>', 'textbookers' );?> <?php echo (get_option('txt_enabled') == TRUE) ? __('<b style="color:green">Włączone</b>', 'textbookers' ) : __('<b style="color:red">Wyłączone</b>', 'textbookers' ) ; ?>
		
		<?php if (get_option('txt_enabled') == TRUE) {
        ?>
                <input type="submit" name="disable_auto_post_scheduler" class="button" value="<?php _e('Wyłącz', 'textbookers' ); ?> &raquo;" />
        <?php } else { ?>
                <input type="submit" name="enable_auto_post_scheduler" class="button" value="<?php _e('Włącz', 'textbookers' ); ?> &raquo;" />
        <?php } ?>
		
		</form></h2>
	&nbsp; &nbsp; &nbsp;
		<h4 style="display:inline">
	<?php _e("Plugin do zamawiania i publikacji treści z serwisu textbookers.com po zadanych parametrach.", 'textbookers' ); ?>
	</h4>
	<hr>
	<a href="<?php echo get_admin_url();?>admin.php?page=textbookers&option=ordered" <?php if ($_GET['option'] == 'ordered') { echo 'style="font-weight:bold;color:green"';}?>><?php _e( 'Zamówione teksty', 'textbookers' );?></a> | <a href="<?php echo get_admin_url();?>admin.php?page=textbookers&option=order" <?php if ($_GET['option'] == 'order') { echo 'style="font-weight:bold;color:green"';}?>><?php _e( 'Dodaj zlecenie', 'textbookers' );?></a> | <a href="<?php echo get_admin_url();?>admin.php?page=textbookers&option=getorder" <?php if ($_GET['option'] == 'getorder') { echo 'style="font-weight:bold;color:green"';}?>><?php _e( 'Pobierz zlecenie', 'textbookers' );?></a> | <a href="<?php echo get_admin_url();?>admin.php?page=textbookers&option=settings" <?php if ($_GET['option'] == 'settings') { echo 'style="font-weight:bold;color:green"';}?>><?php _e( 'Ustawienia', 'textbookers' );?></a> |  <a href="<?php echo get_admin_url();?>admin.php?page=textbookers&option=logs" <?php if ($_GET['option'] == 'logs') { echo 'style="font-weight:bold;color:green"';}?>><?php _e( 'Logi', 'textbookers' );?></a>
	<hr>


		<?php 
			$options = array('ordered','ordered_edit','order','settings','logs','getorder');
			if (in_array($_GET['option'],$options)) {
				include plugin_dir_path(__FILE__) . 'opt_' . $_GET['option'].'.php';
			}
			else if (empty($_GET['option'])) {
				include plugin_dir_path(__FILE__)  . 'opt_' . 'ordered.php';
			}
			else {
				 _e( 'Brak dostępnej opcji', 'textbookers' );
			}                 
			
			
		?>


       
	</div>
<?php
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_time_seconds($num,$timeperiod) {
	if ($timeperiod == 'days')
		$timeval = 3600 * 24;
	else if ($timeperiod == 'hours')
		$timeval = 3600;
	else
		$timeval = 60;
	// is this a range? i.e 2-6? pick a random time between them
	if ( preg_match( "/(\d+)\s*\D+\s*(\d+)/", $num, $matches ) ) {
		$random = mt_rand( $matches[1] * $timeval, $matches[2] * $timeval);
		return $random;
	}
	else
		return (int)($num * $timeval);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_heartbeat() { // absolutely ensure our ERROR event is still scheduled!
    if ( FALSE == get_option('txt_enabled') ) {	//  is not enabled - do nothing
	return;
    }
    if ( wp_next_scheduled( 'txt_textbookers_hook' ) ) { // event hook exists - do nothing
	return;
    }
    // some other code/plugin has stomped our event hook! reset
    txt_write_log( "Notice! ERRORnabled but 'txt_textbookers_hook' mysteriously removed by another plugin. Resetting..." );
    txt_schedule_event();
}
add_action('wp_head', 'txt_heartbeat');

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_set_next_schedule($schedules) {	// add custom time when to check for next auto post
    if ( FALSE == get_option('txt_enabled') ) { //  is not enabled - do nothing
		return $schedules;
    }

    $timesecs = txt_time_seconds(get_option('txt_next'),get_option('txt_next_time'));
    $schedules['txt_schedule'] = array(
        'interval' => $timesecs, 'display' => 'TextBookers Check'
    );
    return $schedules;
}
add_filter('cron_schedules', 'txt_set_next_schedule', 99);

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_time_check() { // check if there are day/hour limits
	$txt_debug = get_option('txt_debug');
	$txt_excludes = get_option('txt_excludes');
	if (!empty($txt_excludes)) {
		$unique_date = date("d-m-Y");
		$yearly_date = date("d-m");
		$month = date("M");
		$day = date("d");
		$exclude_dates = explode(",",$txt_excludes);
		$date = 0;
		foreach($exclude_dates as $ed) {
			if ($ed == $unique_date) {
				$s = 'date'; $date = $unique_date;
			}
			else if ($ed == $yearly_date) {
				$s = 'date'; $date = $yearly_date;
			}
			else if ($ed == $month) {
				$s = 'month'; $date = $month;
			}
			else if ($ed == $day) {
				$s = 'day'; $date = $day;
			}
			if ( $date ) {
				if ($txt_debug) txt_write_log( sprintf( __("DEBUG: today matches excluded %s %s, no post check will occur.", 'textbookers'), $s, $date ) );
				return 0;
			}
		}
	}

	$today = strtolower(date("D",current_time("timestamp")));
	$txt_hours = get_option('txt_hours_' . $today);

	if ($txt_hours == '0') { // 0 = no posts for this day
		if ($txt_debug) txt_write_log( sprintf( __("DEBUG: 0 found for %s, no post check will occur.", 'textbookers'), $today) );
		return 0;
	}
	if (!empty($txt_hours)) {
		$time = date("Hi",current_time("timestamp"));
		$ranges = explode(",",$txt_hours);
		foreach($ranges as $range) {
			$range = preg_replace('/\s+/', '', $range );
			$hours = explode("-",$range);
			if (count($hours) != 2)
				txt_write_log( sprintf (__("Error: %s time range of %s not recognized.", 'textbookers' ), date("l"), $range ) );
			if ( ! is_numeric( $hours[0] ) ) {
				txt_write_log( sprintf (__("Error: %s time range '%s' is not an integer.", 'textbookers' ), date("l"), $hours[0] ) );
			}
			if ( ! is_numeric( $hours[1] ) ) {
				txt_write_log( sprintf (__("Error: %s time range '%s' is not an integer.", 'textbookers' ), date("l"), $hours[1] ) );
			}
			if ($hours[0] <= $time && $time <= $hours[1]) {
				return 1;
			}
		}
		if ($txt_debug) txt_write_log( sprintf( __("DEBUG: current time %s is not in allowed time range for %s (%s - %s), no post check will occur.", 'textbookers'), $time, $today, $hours[0], $hours[1]) );
		return 0;
	}
return 1;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_verify_cron_event() {
	$crons = get_option( 'cron' );
	$events = 0;
	$hook = 'txt_textbookers_hook';
	foreach ( $crons as $timestamp => $cron ) {
		if ( isset( $cron[$hook] ) ) {
			$events++;
		}
	}
	if ( $events > 1 ) {    // only 1 event should be scheduled for the hook. slow db issue/bug?
		// clear all hook events
		wp_clear_scheduled_hook( $hook );

		// set a fresh event 
		wp_schedule_event( time(), 'txt_schedule', 'txt_textbookers_hook' );

		txt_write_log( "CRON: {$hook} hook had {$events} events scheduled (probable reason: database too slow/timed out when WordPress sets events). Resetting." );
		return 0;
	}
	return 1;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// Does the actual cronjob work:
function txt_textbookers() {
	global $wpdb;
	txt_check_log_size();

	$txt_enabled = (bool)get_option('txt_enabled');
	if ($txt_enabled == FALSE) return;

	if (!txt_verify_cron_event()) return;
	if (!txt_time_check()) return;

	$txt_debug = get_option('txt_debug');

	if ($txt_debug) txt_write_log( sprintf( __("DEBUG: txt_textbookers_hook uruchomiony...", 'textbookers') ) );

	$txt_max_per_day = get_option('txt_max_per_day');
	$txt_num_day = explode(",", get_option('txt_num_day')); # example: 4,2 = today the 4th of the month, 2 posts already published today
	$today = date('d',current_time("timestamp",1));
	if ($txt_num_day[0] && $txt_num_day[0] != $today) # if new day, reset num
		$day_num = 0;
	else
		$day_num = isset($txt_num_day[1]) ? $txt_num_day[1] : 0;
	if ($txt_max_per_day && $day_num >= $txt_max_per_day) {
		if ($txt_debug) txt_write_log( sprintf( __("DEBUG: Osiągnięte dzisiejsze (%s dzień miesiąca) maksimum artykułów (%s).", 'textbookers'), $today,$txt_max_per_day) );
		return;
	}
	
	// select post from database
	if ($txt_debug) txt_write_log( __("DEBUG: Sprawdzam czy jest jakieś zamówienie.", 'textbookers') );
	
	$postorder = txt_check_order();
	
	
	if (!$postorder) {
		
		if ($txt_debug) txt_write_log( __("DEBUG: Brak zamówień do sprawdzenia.", 'textbookers') );
		die;
	}
	
	else {
		if ($txt_debug) txt_write_log( __("DEBUG: Sprawdzam zamówienie numer {$postorder['id']}.", 'textbookers') );
	}
	
	// check if article order is ready / API call
	$txt = new textBookersAPI();
	$txt->login(get_option('txt_gt_id_cli'),get_option('txt_gt_sec_cli'),get_option('txt_gt_login'),get_option('txt_gt_pass'));
	$x = $txt->getApi('articles',"order={$postorder['id']}&creationStatus=to-accept");
	if ($txt_debug) txt_write_log(  __("DEBUG -  odpytuję API textbookers", 'textbookers') );
	if ( $x[0]['utilized'] == 0 ) {
		
	if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  znaleziono tekst (%s) dla zamówienia {$postorder['id']}", 'textbookers'), $x[0]['title'] ) );
	
		$id_article = $x[0]['id'];
		$options = $x[0];
		
	
	//tu cron pobieram artykuł np.
	$post = array();
	$post['post_title'] = ($options['title']?$options['title']:$postorder['title']);
	$post['post_content'] = $options['content'];
	$post['tags_input'] = $postorder['tags'];
	$post['post_author'] = $postorder['autors'];
	$post['post_status'] = $postorder['status'];
	if(!empty($postorder['slug'])) {
		$post['post_name'] = trim($postorder['slug']);
	}
	
	if (strlen($postorder['publishdate'])>1) {
		$post['post_date'] = get_date_from_gmt(date('Y-m-d H:i:s',strtotime($postorder['publishdate'])));
	}
	else {
		$post['post_date'] = get_date_from_gmt(date('Y-m-d H:i:s',current_time("timestamp",1)));
		//$post['post_date_gmt'] = get_date_from_gmt(date('Y-m-d H:i:s',current_time("timestamp")));
	}
	$post['post_category'] = $postorder['cats']; //lista kategorii
	
	$num_results = 1;
	if ($num_results>0) {
		
		// cycle through results and update
		$cnt = $min_age = 0;
        	
		
			kses_remove_filters();
			
			$return = wp_insert_post( $post , true );
			
		
			
			if ($txt_debug && $return) txt_write_log( sprintf( __("DEBUG: wpis dodany: %s", 'textbookers'),  $return ) );
			if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  JESTEM OK 1", 'textbookers'), $x[0]['title'] ) );
			
			if (is_numeric($options['image']) && $return) {
				set_post_thumbnail( $return, $options['image'] );
				if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  Ikona wpisu (ID %s) ustawiona.", 'textbookers'), $options['image'] ) );
			}
			else if (strlen($options['image'])>5 && $return) {
				$filename = rand().'.jpg';
				$file = $options['image'];
				$name = explode('/',$file);
				if (strstr(end($name),'.')) {
					$filename = end($name);
				}
				
				$upload_file = wp_upload_bits($filename, null, @file_get_contents($file));
				if(!$upload_file['error']) {
				  //if succesfull insert the new file into the media library (create a new attachment post type)
				  $wp_filetype = wp_check_filetype($filename, null );
				  $attachment = array(
					'post_mime_type' => $wp_filetype['type'],
					'post_parent' => $return,
					'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
					'post_content' => '',
					'post_status' => 'inherit'
				  );
				  //wp_insert_attachment( $attachment, $filename, $parent_post_id );
				  $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $return );
				  if (!is_wp_error($attachment_id)) {
					 //if attachment post was successfully created, insert it as a thumbnail to the post $post_id
					 require_once(ABSPATH . "wp-admin" . '/includes/image.php');
					 //wp_generate_attachment_metadata( $attachment_id, $file ); for images
					 $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
					 wp_update_attachment_metadata( $attachment_id,  $attachment_data );
					 set_post_thumbnail( $return, $attachment_id );
					 if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  Ikona wpisu pobrana.", 'textbookers'), $attachment_id ) );
				   }
				   else {
					   if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  Problem z ikoną wpisu.", 'textbookers'), $attachment_id ) );
				   }
				} else {
					   if ($txt_debug) txt_write_log( sprintf( __("DEBUG -  Problem z ikoną wpisu: %s", 'textbookers'), print_r($upload_file,true)) );
				}
			}
			
			kses_init_filters();

			if ( is_wp_error( $return ) ) {
				txt_write_log( sprintf( __("ERROR: wp_update_post returned %s", 'textbookers'), $return->get_error_message() ) );
			}
			else {
				
			//api set art utilized
				
			$x = $txt->patchApi('articles/'.$id_article,array('utilized'=>'utilized'));
			
			$str = sprintf (__("POST id %d opublikowany : '%s'. Artykuł został oznaczony jako wykorzystany w textbookers.", 'textbookers' ), $return, $post['post_title'] );
			txt_write_log( $str );
			
			//set published in database
			
                $table_name = $wpdb->prefix . 'textbookers_ordered';
		        $logItem = array(
                        'published'  => current_time("timestamp")
                );
				//$wpdb->show_errors = true;
                if ( false === $wpdb->update( $table_name, $logItem, array('id'=>$postorder['id']) ) ) {
					//$wpdb->show_errors();
					txt_write_log("ERROR: wpdb update ordered failed!");
				}
               
			
			$cnt++;
			$day_num++;
			
		
			$txt_num_day = date('d',current_time("timestamp",1)) . "," . $day_num;
        	update_option('txt_num_day', $txt_num_day);
			}
	}


	if ( $txt_debug ) {
		$scheduledtime = wp_next_scheduled('txt_textbookers_hook');
		$formatscheduledtime = date("Y-m-d H:i:s", $scheduledtime + (get_option( 'gmt_offset' ) * HOUR_IN_SECONDS )) . " " . get_option('timezone_string');
		txt_write_log( sprintf( __("DEBUG: wp_next_scheduled for %s.", 'textbookers'), $formatscheduledtime ) );
	}
}
	else if ( $x[0]['order']['status'] == 1 && $x[0]['utilized'] == 1 ) {
		txt_write_log( __("DEBUG -  Ten artykuł (ID:{$x[0]['id']} , TYTUŁ:{$x[0]['title']}) oznaczony jest jako wykorzystany.", 'textbookers' ) );
	}
	else {
		txt_write_log( __("DEBUG -  Ten artykuł (ID:{$x[0]['id']}) nie jest jeszcze gotowy.", 'textbookers' ) );
	}
}
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

function txt_write_log($msg)
{
	        global $wpdb;
                $table_name = $wpdb->prefix . 'textbookers_log';
		$level = ( false !== stripos( $msg, 'error' ) ) ? 0: 1;
                $logItem = array(
                        'date'  => date_i18n('Y-m-d H:i:s'),
                        'level'  => $level,
                        'msg'   => $msg
                );
                if ( false === $wpdb->insert( $table_name, $logItem ) ) {
			error_log("ERROR: wpdb insert failed! [" . $msg . "]");
		}
                return 1;
}

function txt_write_order($order)
{
	        global $wpdb;
                $table_name = $wpdb->prefix . 'textbookers_ordered';
		        $logItem = array(
                        'id'  => $order['id'],
                        'articleTitle'  => (strlen($order['articleTitle'])?$order['articleTitle']:'0'),
                        'createdAt'  => $order['createdAt'],
                        'deadline'  => $order['deadline'],
                        'minChars'  => $order['minChars'],
                        'author'  => (is_int($order['author'])?$order['author']:''),
                        'individual'  => ($order['individual']==true?1:0),
                        'keywords'  => $order['keywords'],
                        'orderDescription'  => (strlen($order['orderDescription'])?$order['orderDescription']:'0'),
                        'msg'  => $order['msg'],
                        'options'  => $order['options']
                );
						
				
				//$wpdb->show_errors = true;
                if ( false === $wpdb->insert( $table_name, $logItem ) ) {
					$wpdb->show_errors();
					$dberr = json_encode($wpdb->print_error(),true);
					txt_write_log("ERROR: wpdb insert to ordered failed: {$dberr}");
				}
                return 1;
}

function txt_edit_order($order)
{
	        global $wpdb;
                $table_name = $wpdb->prefix . 'textbookers_ordered';
		        $logItem = array(
                        'articleTitle'  => (strlen($order['articleTitle'])?$order['articleTitle']:'0'),
                        'options'  => $order['options']
                );
						
				
				//$wpdb->show_errors = true;
                if ( false === $wpdb->update( $table_name, $logItem, array('id'=>$order['id']) ) ) {
					//$wpdb->show_errors();
					txt_write_log("ERROR: wpdb edit ordered failed!");
				}
                return 1;
}

function txt_delete_order($order)
{
	        global $wpdb;
                $table_name = $wpdb->prefix . 'textbookers_ordered';

				
				//$wpdb->show_errors = true;
                if ( false === $wpdb->delete( $table_name, array('id'=>$order) ) ) {
					//$wpdb->show_errors();
					txt_write_log("ERROR: wpdb delete from ordered failed!");
				}
                return 1;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function txt_check_log_size() {
	global $wpdb;

	// first, check log size
	$table_name = $wpdb->prefix . 'textbookers_log';
	$max = (int) get_option( 'txt_max_log', 1000 );
	if ( $max ) {
		$last_id = $wpdb->get_var( "SELECT MAX(ID) FROM ". $table_name );
		$last_id -= $max;
		if ( $last_id > 0 ) {
			$wpdb->query( 'DELETE FROM '. $table_name . ' WHERE id<=' . $last_id );
		}
	}
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function txt_show_log() {
	global $wpdb;

	txt_check_log_size();

	$table_name = $wpdb->prefix . 'textbookers_log';
	$log = $wpdb->get_results( "SELECT * FROM ". $table_name . " ORDER BY id desc", ARRAY_A );
	if ( ! is_array( $log ) || empty( $log ) ) {
		echo "No entries.";
		return;
	}

	foreach ( $log as $logline ) {
		$output = '';
		if ( $logline['level'] == 0 )           $output .= "<span class='aps-error'>{$logline['date']}</span>";
		else if ( $logline['level'] == 1 )      $output .= "<span class='aps-critical'>{$logline['date']}</span>";
		else $output .= "<span class='aps-date'>{$logline['date']}</span>";
		$output .= " - <span class='aps-msg'>{$logline['msg']}</span>";
		$output .= "<br>\n";
		echo $output;
	}
}

///////////////////////////////////////////////////////////////////////////

function txt_show_orders() {
	global $wpdb;

	$table_name = $wpdb->prefix . 'textbookers_ordered';
	$log = $wpdb->get_results( "SELECT * FROM ". $table_name . " ORDER BY id", ARRAY_A );
	if ( ! is_array( $log ) || empty( $log ) ) {
		
		return;
	}

	return $log;
}

////////////////////////////////////////////////////////////////////////////

function txt_get_order($id) {
	global $wpdb;

	$table_name = $wpdb->prefix . 'textbookers_ordered';
	$log = $wpdb->get_results( "SELECT * FROM ". $table_name . " WHERE id={$id}", ARRAY_A );
	if ( ! is_array( $log ) || empty( $log ) ) {
		
		return;
	}
	return $log[0];
	
}


//////////////////////////////////////////////////////////////////////////////////

function txt_check_order() {
	global $wpdb;

	$table_name = $wpdb->prefix . 'textbookers_ordered';
	$log = $wpdb->get_results( "SELECT * FROM ". $table_name . " WHERE published=0 order by checkedAt asc LIMIT 1", ARRAY_A );
	if ( ! is_array( $log ) || empty( $log ) ) {
		
		return;
	}
	
	$logitem = array();
	$logitem['checkedAt'] = current_time("timestamp");
	if ( false === $wpdb->update( $table_name, $logitem, array('id'=>$log[0]['id']) ) ) {
		//$wpdb->show_errors();
		txt_write_log("ERROR: wpdb update ordered failed!");
	}

	return $log[0];
}


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

add_filter('plugin_action_links', 'txt_plugin_action_links', 10, 2);

function txt_plugin_action_links($links, $file) {
    static $this_plugin;

    if (!$this_plugin) {
        $this_plugin = plugin_basename(__FILE__);
    }

    if ($file == $this_plugin) {
        $settings_link = '<a href="' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=textbookers">Settings</a>';
        array_unshift($links, $settings_link);
    }

    return $links;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

add_action( 'publish_post', 'txt_check_for_restart', 10, 2 );

function txt_check_for_restart( $post_id, $post ) {
	// don't restart if post already published
	if ( $post->post_date != $post->post_modified ) return;	

	if (get_option('txt_enabled') == FALSE) return;
	if (get_option('txt_updating') == TRUE) return;
	txt_schedule_event(1);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
?>